@@ -37,4 +37,15 @@ else:
     if if_del == "True":
         if_del = True
     else:
-        if_del = False
\ No newline at end of file
+        if_del = False
+
+# 歌单发送失败时发送的条数
+try:
+    song_num = get_driver().config.music_retry_songnum
+except AttributeError:
+    song_num = 50
+else:
+    try:
+        song_num = int(song_num)
+    except ValueError:
+        song_num = 50
\ No newline at end of file
